
file_id = "REGISTER_ACTIVITY"

--[[

REGISTER_ACTIVITY スクリプト起動時に渡されるパラメータ
---------------------------------------------------------------------------------
キー値				値		           									値の例
---------------------------------------------------------------------------------
RemoteDeviceName	監視用リモートデバイス名							LivingRoom

SerialNumber		監視用リモートデバイスのシリアル番号				0013A200404AC397

ActivityLevel		赤外センサーで関知した動作レベル(カウンタ値)		120

TemperatureLevel		温度センサーの値を A/D 変換した値					35
---------------------------------------------------------------------------------

カウンタ値　   統計用データベースキー名		"SENSOR_IR_" + <SerialNumber>
温度センサAD値 統計用データベースキー名		"SENSOR_TP_" + <SerialNumber>

統計用データベースに登録する値			ActivityLevel を数値に変換した値

]]

local temperature;
local key,val,stat;
local adc_vref = 5.00;

------------------------------------------------------------
-- DeviceServer 起動後に一回だけ SENSOR_AVREF_SETUP スクリプトを実行する
------------------------------------------------------------
stat,val = get_shared_data("DO_SENSOR_AVREF_SETUP")
if not stat then error() end
if val == "" then
	if not inc_shared_data("DO_SENSOR_AVREF_SETUP") then error() end
	if not script_exec("SENSOR_AVREF_SETUP","","") then error() end
end

------------------------------------------------------------
-- ADC Vref 値をデータベースから取得する
------------------------------------------------------------
stat,val = get_permanent_data("AVref_" .. g_params["RemoteDeviceName"])
if not stat then error() end
adc_vref = tonumber(val);

------------------------------------------------------------
-- 温度計算
------------------------------------------------------------
if g_params["SerialNumber"] and g_params["RemoteDeviceName"] and g_params["ActivityLevel"] and g_params["TemperatureLevel"] then
	temperature = (100 * adc_vref * tonumber(g_params["TemperatureLevel"])) / 1024;
	log_msg(string.format("%s IR-count = %s temperature = %2.3g adc_vref = %2.4g",
            g_params["RemoteDeviceName"],g_params["ActivityLevel"],temperature,adc_vref),file_id)
else
	log_msg("*ERROR* parameter error",file_id);
	error();
end;

------------------------------------------------------------
-- デバイス名とシリアル番号をデータベースに登録
------------------------------------------------------------
stat = add_permanent_strlist("TDCPDeviceList",g_params["SerialNumber"] .. "," .. g_params["RemoteDeviceName"],true)
if not stat then error() end

------------------------------------------------------------
-- サンプリング値をデータベースに登録
------------------------------------------------------------
key = "SENSOR_IR_" .. g_params["SerialNumber"]
val = tonumber(g_params["ActivityLevel"])

stat = add_stat_data(key,val)
if not stat then error() end

key = "SENSOR_TP_" .. g_params["SerialNumber"]
stat = add_stat_data(key,tostring(temperature))
if not stat then error() end

------------------------------------------------------------
-- ACTIVITIES_CHECK で、IR センサーが
-- 0 以上のカウンタ値を取得したかどうかをチェックするための
-- フラグを設定する
------------------------------------------------------------
if val > 0 then
	if not set_shared_data("RESIDENTS_ACTIVITIES_FLAG","1") then error() end
end


