
file_id = "SENSOR_DATA_TO_FILE"

--[[

SENSOR_DATA_TO_FILE スクリプト起動時に渡されるパラメータ
---------------------------------------------------------------------------------
キー値				値		           									値の例
---------------------------------------------------------------------------------
TargetDate			集計対象日付(YYYY/MM/DD)							"2010/01/31"
					パラメータ省略時はスクリプトが起動された日付が
					集計対象日になる

OutFile				集計結果(CSV)を出力するファイル名					"e:/summary.csv"
					パラメータ省略時は "c:/summary.csv"になる
---------------------------------------------------------------------------------

]]

log_msg("start..",file_id)

----------------------------------------------------------------------
-- TargetDate パラメータが指定されていない場合にはスクリプトが起動
-- された日を集計対象にする
----------------------------------------------------------------------
local timestamp
if g_params["TargetDate"] then
    timestamp = g_params["TargetDate"] .. " 0:0:0"
else
	local now = os.date "*t"
	timestamp = string.format("%4.4d/%2.2d/%2.2d 0:0:0",now["year"],now["month"],now["day"])
end

local outfile
if g_params["OutFile"] then
	outfile = g_params["OutFile"]
else
	outfile = "c:/summary.csv"
end

----------------------------------------------------------------------
-- 出力ファイルオープン
----------------------------------------------------------------------
local file;
file = io.open(outfile,"w+");
if (file == nil) then error() end;

----------------------------------------------------------------------
-- 統計用データベースに保管された全てのTDCP デバイスを集計対象とする
----------------------------------------------------------------------
local key,val,key_dev,val_dev
local device
local stat,strlist = get_permanent_strlist("TDCPDeviceList")
for key_dev,val_dev in ipairs(strlist) do
	device = csv_to_tbl(val_dev)
	log_msg("SerialNumber=" .. device[1] .. " NodeIdentifier=" .. device[2] ,file_id)

	-------------------------------------
	-- 温度データの集計を行う
	-------------------------------------
	stat,datetime,sample,total,mean,max,min = summary_stat_data("SENSOR_TP_" .. device[1],timestamp,600,144)
	if not stat then error() end
	for key,val in ipairs(datetime) do
		file:write(string.format("TEMPERATURE,%s,%s,%d,%2.3g,%2.3g,%2.3g\n",device[2],val,sample[key],mean[key],max[key],min[key]))
	end

	-------------------------------------
	-- 赤外センサカウンタの集計を行う
	-------------------------------------
	stat,datetime,sample,total,mean,max,min = summary_stat_data("SENSOR_IR_" .. device[1],timestamp,600,144)
	if not stat then error() end
	for key,val in ipairs(datetime) do
		file:write(string.format("IR_COUNT,%s,%s,%d,%4.5g,%4.5g,%4.5g\n",device[2],val,sample[key],mean[key],max[key],min[key]))
	end

end

----------------------------------------------------------------------
-- 出力ファイルクローズ
----------------------------------------------------------------------
file:close();

