
file_id = "SENSOR_DATA_TO_MAIL"

--[[

SENSOR_DATA_TO_MAIL スクリプト起動時に渡されるパラメータ
---------------------------------------------------------------------------------
キー値				値		           									値の例
---------------------------------------------------------------------------------
TargetDate			集計対象日付(YYYY/MM/DD)							"2010/01/31"
					パラメータ省略時はスクリプトが起動された日付が
					集計対象日になる

このスクリプトはメールコマンドから実行されることを想定しています。

---------------------------------------------------------------------------------

]]

log_msg("start..",file_id)

----------------------------------------------------------------------
-- TargetDate パラメータが指定されていない場合にはスクリプトが起動
-- された日を集計対象にする
----------------------------------------------------------------------
local timestamp
if g_params["TargetDate"] then
    timestamp = g_params["TargetDate"] .. " 0:0:0"
else
	local now = os.date "*t"
	timestamp = string.format("%4.4d/%2.2d/%2.2d 0:0:0",now["year"],now["month"],now["day"])
end

----------------------------------------------------------------------
-- 統計用データベースに保管された全てのTDCP デバイスを集計対象とする
----------------------------------------------------------------------
local key,val,key_dev,val_dev
local device
local t_stat,t_datetime,t_sample,t_total,t_mean,t_max,t_min
local ir_stat,ir_datetime,ir_sample,ir_total,ir_mean,ir_max,ir_min

local body = {}

local stat,strlist = get_permanent_strlist("TDCPDeviceList")
for key_dev,val_dev in ipairs(strlist) do
	device = csv_to_tbl(val_dev)
	log_msg("SerialNumber=" .. device[1] .. " NodeIdentifier=" .. device[2] ,file_id)

	-------------------------------------
	-- 温度データ集計
	-------------------------------------
	t_stat,t_datetime,t_sample,t_total,t_mean,t_max,t_min = 
                   summary_stat_data("SENSOR_TP_" .. device[1],timestamp,600,144)
	if not t_stat then error() end

	-------------------------------------
	-- 赤外センサカウンタ集計
	-------------------------------------
	ir_stat,ir_datetime,ir_sample,ir_total,ir_mean,ir_max,ir_min = 
                  summary_stat_data("SENSOR_IR_" .. device[1],timestamp,600,144)
	if not ir_stat then error() end

	-------------------------------------
	-- 集計データ出力
	-------------------------------------
	table.insert(body,"----------------------------------")
	table.insert(body,"デバイス " .. device[2] .. "  日付: " .. string.sub(timestamp,1,10))
	table.insert(body,"サンプル  温度 IR平均/ IR最大")
	table.insert(body,"----------------------------------")
	for key,val in ipairs(t_datetime) do
		if t_sample[key] == 0 then
			table.insert(body,string.format("%s -",string.sub(val,12,16)))
		else
			table.insert(body,string.format("%s [%d] %4.1f %6.1f/%6.1f",string.sub(val,12,16),t_sample[key],t_mean[key],ir_mean[key],ir_max[key]))
		end
	end

end

----------------------------------------------------------------------
-- 集計結果をメールで送信する
----------------------------------------------------------------------
if not mail_send(g_params["$REPLYTO$"],"","センサーデータ集計",unpack(body)) then error() end


