
file_id = "XBEE_TDCP_DATA"

--[[

******************************************************************************
* イベントハンドラスクリプト実行時間について                                 *
******************************************************************************

一つのスクリプトの実行は長くても数秒以内で必ず終了するようにしてください。
処理に時間がかかると、イベント処理の終了を待つサーバー側でタイムアウトが発生します。

また、同時実行可能なスクリプトの数に制限があるため、他のスクリプトの実行開始が
待たされる原因にもなります。

頻繁には発生しないイベントで、処理時間がかかるスクリプトを実行したい場合は
スクリプトを別に作成して、このイベントハンドラ中から script_fork_exec() を使用して
別スレッドで実行することを検討してください。

******************************************************************************


XBEE_TDCP_DATA スクリプト起動時に渡される追加パラメータ

---------------------------------------------------------------------------------
キー値			値		            									値の例
---------------------------------------------------------------------------------
APIType			フレームデータ中のAPI Type(16進数2桁)					81

SourceAddress	フレームデータ中のSourceAddress
				16bit アドレスの場合(16進数4桁)							0A01
				64bit アドレスの場合(16進数16桁)						0013A200404AC397

SerialNumber	XBee デバイスの SerialNumber
				DeviceServer に保持されたマスターファイルを使用して、
				SourceAddress から変換した値が設定される。				0013A200404AC397

NodeIdentifier	XBee デバイスの NodeIdentifier。
				DeviceServer に保持されたマスターファイルを使用して、
				SourceAddress から変換した値が設定される。				Device1

RSSI			フレームデータ中のRSSI(16進数2桁)						45

Options			フレームデータ中Options									00

TDCP_COUNT		TDCP データカラム数										2

TDCP_<Column#>	TDCP データ値(ASCII 文字列)
				TDCP_1 は常にコマンドプリフィックス文字列を表す			"$$$1234"
				"$$$" で始まり、0文字以上の任意の文字列が後に続く。

				TDCP_2 はコマンド実行ステータスを表す					"1"
				"1" はコマンド実行成功、"0" は失敗を示す				
				イベントデータの場合にはイベント名が入る


				TDCP_3以降のデータはTDCPコマンド毎に決められた、
				オプション文字列が入る	

				<Column#> には 最大、TDCP_COUNT まで 1から順番に
				インクリメントされた値が入る。

]]


------------------
-- BEGIN SCRIPT --
------------------
local rf_data = "";
local tkey,i;
local max_idx = tonumber(g_params["TDCP_COUNT"]);
for i = 1,max_idx,1 do
	tkey = "TDCP_" .. tostring(i);
	if (i == 1) then
		rf_data = g_params[tkey]
	else
		rf_data = rf_data .. "," .. g_params[tkey]
	end;
end;
log_msg(g_params["NodeIdentifier"] .. "[" .. g_params["SourceAddress"] .. "," .. g_params["SerialNumber"] .. "] RFData = " .. rf_data,file_id)

---------------------------------------------------------------------------
-- サンプリングイベントを受信した場合は統計用データベースに登録するための
-- スクリプトを実行する。
---------------------------------------------------------------------------
local stat;
if g_params["TDCP_2"] == "SAMPLING" and g_params["TDCP_4"] == "8" then
	local key_list = list_to_csv("SerialNumber","RemoteDeviceName","ActivityLevel","TemperatureLevel")
	local val_list = list_to_csv(g_params["SerialNumber"],g_params["NodeIdentifier"],g_params["TDCP_6"],g_params["TDCP_10"])

	stat = script_fork_exec("REGISTER_ACTIVITY",key_list,val_list)
	if not stat then error() end
end

---------------------------------------------------------------------------
-- COUNT_EXCEED イベントを受信した場合は、アラートメール送信のための
-- スクリプトを実行する
---------------------------------------------------------------------------
local stat;
if g_params["TDCP_2"] == "COUNT_EXCEED" and g_params["TDCP_4"] == "8" then
	local key_list = list_to_csv("SerialNumber","RemoteDeviceName","ActivityLevel")
	local val_list = list_to_csv(g_params["SerialNumber"],g_params["NodeIdentifier"],g_params["TDCP_5"])

	stat = script_fork_exec("IR_SENSOR_ALERT_MAIL",key_list,val_list)
	if not stat then error() end
end



------------------
-- END SCRIPT   --
------------------

